
--
-- Pretty file tree with various sources
--
-- Source: https://github.com/nvim-neo-tree/neo-tree.nvim
-- ..............................................
--
-- Author: Sven Vogel
-- Created: 01.11.2024
-- Edited: 07.11.2024
--
-- ==============================================

ui = require 'config.ui'

return {
    "nvim-neo-tree/neo-tree.nvim",
    lazy = false,
    branch = "v3.x",
    dependencies = {
        "nvim-lua/plenary.nvim",
        "nvim-tree/nvim-web-devicons",
        "MunifTanjim/nui.nvim"
    },
    cmd = "Neotree",
    opts = {
        popup_border_style = ui.border,
        source_selector = {
            winbar = true,
            statusline = false,
            sources = {                    
          {
            source = "filesystem",         
            display_name = " 󰉓 Files "     
          },
          {
            source = "buffers",            
            display_name = " 󰈚 Buffers "   
          },
          {
            source = "document_symbols",         
            display_name = " 󰊢 Git "    
          },
        },
        },
	    filesystem = {
            bind_to_cwd = false,
      	    follow_current_file = { enabled = true },
      	    use_libuv_file_watcher = true,
            hijack_netrw_behavior = "open_default",
            filtered_items = {
                hide_dotfiles = false,
                hide_gitignored = false,
                hide_hidden = false, -- only works on Windows for hidden files/directories
            },
            window = {
                position = "left"
            }
        },
        close_if_last_window = false,
	    default_component_configs = {
            container = {
                enable_character_fade = true
            },
            indent = {
                indent_size = 2,
                padding = 1, -- extra padding on left hand side
                with_markers = true,
                indent_marker = "│",
                last_indent_marker = "└",
            with_expanders = true, -- if nil and file nesting is enabled, will enable expanders
            expander_collapsed = "",
            expander_expanded = "",
            expander_highlight = "NeoTreeExpander",
          }
        }
    }
}
